users.Me (My settings) — amici1

# `users.Me` (My settings)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.EmailField: email>`

- `<lino.utils.mldbc.fields.LanguageField: language>`

- `<django.db.models.fields.DateTimeField: modified>`

- `<django.db.models.fields.DateTimeField: created>`

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

- `<django.db.models.fields.CharField: password>`

- `<django.db.models.fields.DateTimeField: last_login>`

- `<django.db.models.fields.CharField: username>`

- `<lino.core.choicelists.ChoiceListField: user_type>`

- `<django.db.models.fields.CharField: initials>`

- `<django.db.models.fields.CharField: first_name>`

- `<django.db.models.fields.CharField: last_name>`

- `<django.db.models.fields.TextField: remarks>`

- `<django.db.models.fields.related.ForeignKey: partner>`

- `<lino.core.choicelists.ChoiceListField: time_zone>`

- `<lino.core.choicelists.ChoiceListField: date_format>`

- `<lino.core.choicelists.ChoiceListField: dashboard_layout>`

- `<lino.core.choicelists.ChoiceListField: access_class>`

- `<django.db.models.fields.related.ForeignKey: event_type>`

Detail fields

- `<Panel general in lino_amici.lib.users.desktop.UserDetail on lino.modlib.users.desktop.Users>`

- `<Panel calendar in lino_amici.lib.users.desktop.UserDetail on lino.modlib.users.desktop.Users>`

- `<GridElement dashboard.WidgetsByUser in lino_amici.lib.users.desktop.UserDetail on lino.modlib.users.desktop.Users>`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- Create (submit_insert) : Create the record and open a detail window on it

- Detail (detail) : Open a detail window on this record.

- Change password (change_password) : Change the password of this user.

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- My settings (my_settings) : See `<lino.modlib.users.actions.MySettings my_settings ('My settings')>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

- Welcome mail (send_welcome_email) : Send a welcome mail to this user.

- Sign out (sign_out) : Sign out the current user and return to the welcome screen for anonymous visitors.

- Update widgets (update_widgets) : Create or update the dashboard widgets for this user.

- None (validate) : See `<lino.core.actions.ValidateForm validate>`.

- Save (submit_detail) : Save changes in this form

Filter parameters

- `<lino.core.choicelists.ChoiceListField: user_type>`

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

## Filter parameters